from docsend2pdf import DocSendClient
from docsend2pdf.exceptions import InvalidCredentialsError, InvalidURLError

import hashlib

docsend_client = DocSendClient()

EMAIL = 'samuel@cmcc.vc'

def test_get_pdf_with_passcode():
    wave_url = 'https://docsend.com/view/2edsymvxs54ykh6i'
    pdf = docsend_client.get_pdf(wave_url, email=EMAIL, passcode='WaveWorld2024@')
    hash = hashlib.sha256(pdf).hexdigest()

    assert isinstance(pdf, bytes)
    assert pdf.startswith(b'%PDF-')
    assert hash == 'e7b0b84e03460dadd9afb71999ff1704b910987bb0ba021eed5798b025d82390'

def test_get_pdf_without_passcode():
    moemate_url = 'https://docsend.com/view/cgi7tgiscuj8dzga'
    pdf = docsend_client.get_pdf(moemate_url, email=EMAIL)
    hash = hashlib.sha256(pdf).hexdigest()

    assert isinstance(pdf, bytes)
    assert pdf.startswith(b'%PDF-')
    assert hash == '7ddda305958b36300d6fc254529194005b354467c178dd57ed40bc315e3fddc4'

def test_get_pdf_with_invalid_passcode():
    try:
        wave_url = 'https://docsend.com/view/2edsymvxs54ykh6i'
        docsend_client.get_pdf(wave_url, email=EMAIL, passcode='wrongpasscode')
    except Exception as e:
        assert isinstance(e, InvalidCredentialsError)

def test_get_pdf_with_invalid_url():
    try:
        docsend_client.get_pdf('https://docsend.com/view/somefakeurl', email=EMAIL, passcode='wrongpasscode')
    except Exception as e:
        assert isinstance(e, InvalidURLError)